@@ -5,6 +5,7 @@
 # runs autotools to create ./configure and friends
 #
 # configure depends on version.m4, but autoreconf does not realize this
-rm configure
-autoreconf -Wall -v --install || exit 1
-./configure "$@"
+dir=`dirname $0`
+rm $dir/configure
+(cd $dir && autoreconf -Wall -v --install) || exit 1
+$dir/configure "$@"
