@@ -64,7 +64,7 @@ AtomListPtr  NewAtomList (AtomListPtr next, Atom atom);
  * still work correctly.
  */
 
-#if HAVE_STDINT_H
+#ifdef HAVE_STDINT_H
 
 # include <stdint.h>
 
@@ -73,7 +73,7 @@ AtomListPtr  NewAtomList (AtomListPtr next, Atom atom);
 #define IntToPtr(i)	((void *) (intptr_t) (i))
 #define UIntToPtr(u)	((void *) (uintptr_t) (u))
 
-# if HAVE_UINT64_T
+# ifdef HAVE_UINT64_T
 
 /*
  * If stdint.h defines a 64 bit datatype, use 32 bit
@@ -180,7 +180,7 @@ typedef int HashValue;
 typedef struct _natural {
     DataType	*type;
     int		length;
-    digit	digits[0];
+    digit	digits[];
 } Natural;
 
 static inline int NaturalLength(Natural *n)
@@ -217,7 +217,7 @@ Natural	*NaturalRsl (Natural *v, int shift);
 Natural	*NaturalLsl (Natural *v, int shift);
 Natural	*NaturalMask (Natural *v, int bits);
 int	NaturalPowerOfTwo (Natural *v);
-int	NaturalEstimateLength (Natural *, int base);
+int	NaturalEstimateLength (Natural *, digit base);
 void	NaturalCopy (Natural *, Natural *);
 Bool	NaturalZero (Natural *);
 Bool	NaturalEven (Natural *);
@@ -598,7 +598,7 @@ typedef struct _float {
 
 typedef struct _string {
     BaseValue	    base;
-    long	    length;
+    size_t	    length;
     char	    chars[0];
 } String;
 
@@ -989,7 +989,7 @@ static inline Value BoxValueGet(Box *box, long e) {
 	return BoxElements(box)[e];
 }
 
-static inline Bool BoxConstant(Box *box, int e) {
+static inline Bool BoxConstant(Box *box) {
 	return box->constant;
 }
 
@@ -1098,7 +1098,7 @@ static inline TypePtr RefType (Value r) {
 }
 
 static inline Bool RefConstant(Value r) {
-	return BoxConstant(r->ref.box, r->ref.element);
+	return BoxConstant(r->ref.box);
 }
 
 Value	NewInteger (Sign sign, Natural *mag);
@@ -1195,8 +1195,8 @@ int	FileInput (Value);
 int	FileOutput (Value, char);
 void	FileUnput (Value, unsigned char);
 int	FileInchar (Value);
-int	FileOutchar (Value, int);
-void	FileUnchar (Value, int);
+int	FileOutchar (Value, uint32_t);
+void	FileUnchar (Value, uint32_t);
 Value   FileCreate (int fd, int flags);
 int	FileFlush (Value, Bool block);
 int	FileClose (Value);
